# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

_Public Classes_

* [`gpfs`](#gpfs): base GPFS class
* [`gpfs::ces`](#gpfsces): GPFS CES class
* [`gpfs::client`](#gpfsclient): GPFS client class
* [`gpfs::gui`](#gpfsgui): GPFS GUI class
* [`gpfs::server`](#gpfsserver): GPFS server class

_Private Classes_

* `gpfs::ces::config`: Manage GPFS CES config
* `gpfs::ces::install`: Manage GPFS CES install
* `gpfs::client::config`: Manage GPFS client config
* `gpfs::client::install`: Manage GPFS client install
* `gpfs::gui::config`: Manage GPFS GUI config
* `gpfs::gui::install`: Manage GPFS GUI install
* `gpfs::gui::service`: Manage GPFS GUI services
* `gpfs::install`: Manage GPFS installs
* `gpfs::repo`: Manage GPFS repo
* `gpfs::server::config`: Manage GPFS NSD config
* `gpfs::server::install`: Manage GPFS NSD install

**Defined types**

* [`gpfs::client::rkm`](#gpfsclientrkm): Manage GPFS client ISKLM configuration

**Resource types**

* [`gpfs_config`](#gpfs_config): GPFS config
* [`gpfs_fileset`](#gpfs_fileset): Manage a GPFS fileset
* [`gpfs_fileset_quota`](#gpfs_fileset_quota): Set a GPFS fileset quota
* [`scalemgmt_config`](#scalemgmt_config): scalemgmt config
* [`scalemgmt_conn_validator`](#scalemgmt_conn_validator): Verify that a connection can be successfully established between a node and the scalemgmt server.  Its primary use is as a precondition to pr

## Classes

### gpfs

base GPFS class

#### Examples

##### 

```puppet
include ::gpfs
```

#### Parameters

The following parameters are available in the `gpfs` class.

##### `manage_repo`

Data type: `Boolean`

Sets if GPFS repo should be managed

Default value: `true`

##### `repo_baseurl`

Data type: `Optional[String]`

The GPFS repo baseurl

Default value: `undef`

##### `manage_packages`

Data type: `Boolean`

Determines if GPFS packages should be managed

Default value: `true`

##### `package_ensure`

Data type: `String`

GPFS package ensure property

Default value: 'present'

##### `packages`

Data type: `Array`

GPFS base packages

Default value: [ "gpfs.gplbin-${facts['kernelrelease']}",
    'gpfs.adv',
    'gpfs.base',
    'gpfs.crypto',
    'gpfs.docs',
    'gpfs.ext',
    'gpfs.gpl',
    'gpfs.gskit',
    'gpfs.msg.en_US',
  ]

### gpfs::ces

GPFS CES class

#### Examples

##### 

```puppet
include ::gpfs::ces
```

#### Parameters

The following parameters are available in the `gpfs::ces` class.

##### `manage_packages`

Data type: `Boolean`

Determines if GPFS CES packages should be managed

Default value: `true`

##### `package_ensure`

Data type: `String`

GPFS CES package ensure property

Default value: 'present'

##### `packages`

Data type: `Array`

GPFS CES packages

Default value: [
    'gpfs.java',
    'gpfs.smb',
    'nfs-ganesha',
    'nfs-ganesha-gpfs',
    'nfs-ganesha-utils',
  ]

### gpfs::client

GPFS client class

#### Examples

##### 

```puppet
include ::gpfs::client
```

#### Parameters

The following parameters are available in the `gpfs::client` class.

##### `manage_packages`

Data type: `Boolean`

Determines if GPFS client packages should be managed

Default value: `true`

##### `package_ensure`

Data type: `Any`

GPFS client package ensure property

Default value: 'present'

##### `packages`

Data type: `Any`

GPFS client packages

Default value: []

##### `manage_ssh_authorized_keys`

Data type: `Boolean`

Determines if SSH authorized_keys should be managed

Default value: `true`

##### `ssh_user`

Data type: `Any`

SSH user for GPFS

Default value: 'root'

##### `ssh_authorized_keys`

Data type: `Any`

SSH authorized keys for NSDs

Default value: {}

##### `rkms`

Data type: `Any`

Hash to define gpfs::client::rkm resources

Default value: {}

### gpfs::gui

GPFS GUI class

#### Examples

##### 

```puppet
include ::gpfs::gui
```

#### Parameters

The following parameters are available in the `gpfs::gui` class.

##### `manage_packages`

Data type: `Boolean`

Determines if GPFS GUI packages should be managed

Default value: `true`

##### `package_ensure`

Data type: `String`

GPFS GUI package ensure property

Default value: 'present'

##### `packages`

Data type: `Array`

GPFS GUI packages

Default value: [
    'gpfs.gui',
  ]

##### `manage_firewall`

Data type: `Boolean`

Determines if firewall should be managed

Default value: `true`

##### `firewall_source`

Data type: `Optional[Variant[String, Array]]`

Firewall source value

Default value: `undef`

### gpfs::server

GPFS server class

#### Examples

##### 

```puppet
include ::gpfs::server
```

#### Parameters

The following parameters are available in the `gpfs::server` class.

##### `manage_packages`

Data type: `Boolean`

Determines if GPFS server packages should be managed

Default value: `true`

##### `package_ensure`

Data type: `String`

GPFS server package ensure property

Default value: 'present'

##### `packages`

Data type: `Array`

GPFS server packages

Default value: []

##### `bin_paths`

Data type: `Array`

Paths to add to PATH

Default value: ['/usr/lpp/mmfs/bin']

##### `config_filesystems`

Data type: `Optional[Array]`

Filesystems where filesets are managed by Puppet

Default value: `undef`

## Defined types

### gpfs::client::rkm

Manage GPFS client ISKLM configuration

#### Parameters

The following parameters are available in the `gpfs::client::rkm` defined type.

##### `rkm_id`

Data type: `Any`



Default value: $name

##### `type`

Data type: `Any`



Default value: 'ISKLM'

##### `kmip_server_uris`

Data type: `Array`



Default value: []

##### `key_store`

Data type: `Any`



Default value: '/var/mmfs/etc/RKMcerts/ISKLM.proj2'

##### `key_store_source`

Data type: `Any`



Default value: `undef`

##### `passphrase`

Data type: `Any`



Default value: `undef`

##### `client_cert_label`

Data type: `Any`



Default value: `undef`

##### `tenant_name`

Data type: `Any`



Default value: `undef`

##### `connection_timeout`

Data type: `Any`



Default value: '5'

##### `connection_attempts`

Data type: `Any`



Default value: '3'

##### `retry_sleep`

Data type: `Any`



Default value: '50000'

##### `order`

Data type: `Any`



Default value: '10'

## Resource types

### gpfs_config

GPFS config

#### Parameters

The following parameters are available in the `gpfs_config` type.

##### `name`

namevar

GPFS config

##### `filesystems`

Filesystems to manage

### gpfs_fileset

Manage a GPFS fileset

#### Examples

##### Create `test` GPFS fileset

```puppet
gpfs_fileset { 'test':
  filesystem      => 'project',
  path            => '/gpfs/project/test',
  owner           => 'nobody:wheel',
  permissions     => '1770',
  inode_space     => 'new',
  max_num_inodes  => 1000000,
  alloc_inodes    => 1000000,
}
```

#### Properties

The following properties are available in the `gpfs_fileset` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `path`

The GPFS fileset path.

##### `owner`

Owner of GPFS fileset: user:group

##### `max_num_inodes`

Max number of inodes for fileset.

##### `alloc_inodes`

Allocated inodes for fileset.

#### Parameters

The following parameters are available in the `gpfs_fileset` type.

##### `name`

namevar

The default namevar.

##### `fileset`

The GPFS fileset name.

##### `filesystem`

The GPFS filesystem name.

##### `permissions`

Permissions of fileset.

##### `inode_space`

inodeSpace of fileset.

Default value: new

##### `new_statefile`

Statefile that is created at root of a new fileset

### gpfs_fileset_quota

**Autorequires**:
  * `gpfs_fileset` - Puppet will autorequire the `gpfs_fileset` resource defined in `fileset` property.

#### Examples

##### Add fileset quota to `test` fileset.

```puppet
gpfs_fileset_quota { 'test':
  filesystem => 'project',
  block_soft_limit  => '5T',
  block_hard_limit  => '5T',
  files_soft_limit  => 1000000,
  files_hard_limit  => 1000000,
}
```

#### Properties

The following properties are available in the `gpfs_fileset_quota` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `block_soft_limit`

blockSoftLimit of quota

##### `block_hard_limit`

blockHardLimit of quota

##### `files_soft_limit`

filesSoftLimit of quota

##### `files_hard_limit`

filesHardLimit of quota

#### Parameters

The following parameters are available in the `gpfs_fileset_quota` type.

##### `name`

namevar

The default namevar

##### `filesystem`

The GPFS filesystem name.

##### `fileset`

The GPFS fileset name.

##### `object_name`

The GPFS quota object name

##### `type`

Quota type

Default value: fileset

### scalemgmt_config

scalemgmt config

#### Parameters

The following parameters are available in the `scalemgmt_config` type.

##### `name`

namevar

scalemgmt config

##### `base_url`

Base URL of GPFS API

Default value: https://localhost:443/scalemgmt/

##### `api_user`

API user

Default value: admin

##### `api_password`

API password

Default value: admin001

### scalemgmt_conn_validator

Verify that a connection can be successfully established between a node
and the scalemgmt server.  Its primary use is as a precondition to
prevent configuration changes from being applied if the scalemgmt
server cannot be reached, but it could potentially be used for other
purposes such as monitoring.

#### Properties

The following properties are available in the `scalemgmt_conn_validator` type.

##### `ensure`

Valid values: present, absent

Ensure

Default value: present

#### Parameters

The following parameters are available in the `scalemgmt_conn_validator` type.

##### `name`

namevar

An arbitrary name used as the identity of the resource.

##### `scalemgmt_server`

The DNS name or IP address of the server where scalemgmt should be running.

Default value: localhost

##### `scalemgmt_port`

The port that the scalemgmt server should be listening on.

Default value: 443

##### `api_user`

API user name

Default value: admin

##### `api_password`

API password

Default value: admin001

##### `test_url`

URL to use for testing if the scalemgmt API is up

Default value: /scalemgmt/v2/info

##### `timeout`

The max number of seconds that the validator should wait before giving up and deciding that scalemgmt is not running; defaults to 30 seconds.

Default value: 30

